.. RISC-V Model documentation master file, created by
   sphinx-quickstart on Thu Oct 25 17:11:40 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to RISC-V Model's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   dev

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
